@@ -39,15 +39,15 @@ class Verifier (object):
         in "with" statements.
     """
     
-    def __init__ (self, basedir):
+    def __init__(self, basedir):
         """
             initializes a new verifier using the given base directory.
         """
-        self.base_dir   = basedir
+        self.base_dir = basedir
         self.executions = []
 
 
-    def called (self, command):
+    def called(self, command):
         """
             raises an exception when no more executions are available or
             when the current execution does not have the expected command
@@ -57,17 +57,16 @@ class Verifier (object):
         if not self.executions:
             raise VerificationException('No more further executions: command "%s" can not be verified.' % command)
         
-        actual_execution = self.executions[0]
+        actual_execution = self.executions.pop(0)
         if actual_execution.command_input.command != command:
             raise VerificationException('Execution does not fulfill expectation:\n'
-                                 'Expected command "%s", but got "%s"\n'
-                                 % (command, actual_execution.command_input.command))
+                                        'Expected command "%s", but got "%s"\n'
+                                        % (command, actual_execution.command_input.command))
         
-        self.executions = self.executions[1:]
-        return VerifiableExecutionWrapper(actual_execution)
+        return CommandInputVerifier(actual_execution.command_input)
     
     
-    def verify (self, command, arguments, stdin=None):
+    def verify(self, command, arguments, stdin=None):
         """
             raises an exception when no more executions are available or
             when the current execution does not fulfill the given
@@ -82,9 +81,9 @@ class Verifier (object):
         actual_execution = self.executions[0]
         if not actual_execution.command_input.fulfills(expected_input):
             raise VerificationException('Execution does not fulfill expected_input:\n'
-                                 'Expected %s\n'
-                                 'Actual   %s\n'
-                                 % (expected_input, actual_execution))
+                                        'Expected %s\n'
+                                        'Actual   %s\n'
+                                        % (expected_input, actual_execution))
         
         self.executions = self.executions[1:]
     
@@ -133,23 +132,27 @@ class Verifier (object):
             raise VerificationException(message)
 
 
-class VerifiableExecutionWrapper (object):
+class CommandInputVerifier (object):
     """
         Verifier.called returns this wrapper to make a fluent interface
         possible.
     """
     
-    
-    def __init__ (self, execution):
+    def __init__(self, command_input):
         """
-            stores the given execution and assures and_input = with_input.
+            stores command, arguments and stdin and assures
+            and_input = with_input,
+            and_at_least_one_argument_matches = at_least_one_argument_matches
         """
-        self.execution = execution
+        self.command = command_input.command
+        self.arguments = command_input.arguments
+        self.stdin = command_input.stdin
+
         self.and_input = self.with_input
         self.and_at_least_one_argument_matches = self.at_least_one_argument_matches
 
 
-    def at_least_with_arguments (self, *expected_arguments):
+    def at_least_with_arguments(self, *expected_arguments):
         """
             raises an exception if the expeceted arguments are not in the
             arguments of the wrapped execution. Returns the wrapper itself
@@ -158,15 +161,15 @@ class VerifiableExecutionWrapper (object):
         arguments = list(expected_arguments)
         
         for argument in arguments:
-            if argument not in self.execution.command_input.arguments:
+            if argument not in self.arguments:
                 raise VerificationException(
                     'Stub "%s" has not been executed with at least expected arguments %s, but with %s.'
-                    % (self.execution.command_input.command, arguments, self.execution.command_input.arguments))
+                    % (self.command, arguments, self.arguments))
         
         return self
 
 
-    def with_arguments (self, *expected_arguments):
+    def with_arguments(self, *expected_arguments):
         """
             raises an exception if the arguments of the wrapped execution are
             different than the expected arguments. Returns the wrapper itself
@@ -174,37 +177,38 @@ class VerifiableExecutionWrapper (object):
         """
         arguments = list(expected_arguments)
         
-        if self.execution.command_input.arguments != arguments:
+        if self.arguments != arguments:
             raise VerificationException(
                 'Stub "%s" has not been executed with expected arguments %s, but with %s.'
-                % (self.execution.command_input.command, arguments, self.execution.command_input.arguments))
+                % (self.command, arguments, self.arguments))
         
         return self
 
 
-    def with_input (self, expected_stdin):
+    def with_input(self, expected_stdin):
         """
             raises an exception if the input from stdin in the wrapped execution
             is different than the expected stdin input. Returns the wrapper
             itself to make invocation chaining possible.
         """
-        if self.execution.command_input.stdin != expected_stdin:
+        if self.stdin != expected_stdin:
             raise VerificationException(
                 'Stub "%s" has not received the expected stdin "%s", but got "%s".'
-                % (self.execution.command_input.command, expected_stdin, self.execution.command_input.stdin))
+                % (self.command, expected_stdin, self.stdin))
         
         return self
 
+
     def at_least_one_argument_matches(self, pattern):
         """
             raises an exception if none of the arguments matches the given pattern.
         """
         compiled_pattern = re.compile(pattern)
 
-        for argument in self.execution.command_input.arguments:
+        for argument in self.arguments:
             if compiled_pattern.match(argument):
                 return self
 
         raise VerificationException(
             'Stub "{0}" has not been executed with at least one argument matching pattern "{1}",\ngot arguments {2}' \
-                .format(self.execution.command_input.command, pattern, self.execution.command_input.arguments))
\ No newline at end of file
+                .format(self.command, pattern, self.arguments))
